# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sheet
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from .data_import_mode import DataImportMode as DataImportMode_d4630c9b

class DatabaseImportDescriptor(ABC):
    """
    Service Class

    represents a description of how data from an external database is imported.
    
    **since**
    
        OOo 2.0

    See Also:
        `API DatabaseImportDescriptor <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseImportDescriptor.html>`_
    """
    @property
    def ConnectionResource(self) -> str:
        """
        indicates a connection URL, which locates a database driver.
        
        **since**
        
            OOo 2.0
        """
    @property
    def DatabaseName(self) -> str:
        """
        specifies the name of the database from which data is imported.
        """
    @property
    def IsNative(self) -> bool:
        """
        specifies whether the SQL statement is given directly to the database or is parsed before.
        
        **since**
        
            OOo 2.0
        """
    @property
    def SourceObject(self) -> str:
        """
        specifies the table, query, or statement from which data is imported.
        
        The meaning of this is determined by the DatabaseImportDescriptor.SourceType attribute.
        """
    @property
    def SourceType(self) -> 'DataImportMode_d4630c9b':
        """
        enables importing and specifies from what type of source data is imported.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.2
from typing_extensions import Literal
from .open_command_argument2 import OpenCommandArgument2 as OpenCommandArgument2_9210e08
from ..beans.property import Property as Property_8f4e0a76
from ..uno.x_interface import XInterface as XInterface_8f010a43
from .numbered_sorting_info import NumberedSortingInfo as NumberedSortingInfo_fd0e0de6
import typing
from ..beans.named_value import NamedValue as NamedValue_a37a0af3


class OpenCommandArgument3(OpenCommandArgument2_9210e08):
    """
    Struct Class

    Extended argument for commands like \"open\".
    
    We're extending OpenCommandArgument even more, to provide some opening flags on to webdav.

    See Also:
        `API OpenCommandArgument3 <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1OpenCommandArgument3.html>`_
    """
    typeName: Literal['com.sun.star.ucb.OpenCommandArgument3']

    def __init__(self, Properties: typing.Optional[typing.Tuple[Property_8f4e0a76, ...]] = ..., Mode: typing.Optional[int] = ..., Priority: typing.Optional[int] = ..., Sink: typing.Optional[XInterface_8f010a43] = ..., SortingInfo: typing.Optional[typing.Tuple[NumberedSortingInfo_fd0e0de6, ...]] = ..., OpeningFlags: typing.Optional[typing.Tuple[NamedValue_a37a0af3, ...]] = ...) -> None:
        """
        Constructor

        Arguments:
            Properties (typing.Tuple[Property, ...], optional): Properties value.
            Mode (int, optional): Mode value.
            Priority (int, optional): Priority value.
            Sink (XInterface, optional): Sink value.
            SortingInfo (typing.Tuple[NumberedSortingInfo, ...], optional): SortingInfo value.
            OpeningFlags (typing.Tuple[NamedValue, ...], optional): OpeningFlags value.
        """


    @property
    def OpeningFlags(self) -> typing.Tuple[NamedValue_a37a0af3, ...]:
        """
        Flags to use for opening.
        
        WebDav e.g. uses \"KeepAlive\" to enable/disable the respective http feature.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.task
from typing_extensions import Literal
import typing
from .x_master_password_handling import XMasterPasswordHandling as XMasterPasswordHandling_49900ff7
if typing.TYPE_CHECKING:
    from .x_interaction_handler import XInteractionHandler as XInteractionHandler_bf80e51

class XMasterPasswordHandling2(XMasterPasswordHandling_49900ff7):
    """
    allows to change the master password, or let it be requested and checked.

    See Also:
        `API XMasterPasswordHandling2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1task_1_1XMasterPasswordHandling2.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.task.XMasterPasswordHandling2']

    def isDefaultMasterPasswordUsed(self) -> bool:
        """
        allows to detect whether the default master password is used
        """
    def useDefaultMasterPassword(self, xHandler: 'XInteractionHandler_bf80e51') -> bool:
        """
        allows to let the default password be used
        
        Please use this method with care. Using of default master password let the passwords be stored non-encrypted. If a master password is predefined in the algorithm it is no more an encryption, it is just an encoding.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.animations
from typing_extensions import Literal
from .x_animate import XAnimate as XAnimate_ca680c52

class XTransitionFilter(XAnimate_ca680c52):
    """
    Base members XAnimate.Values, XAnimate.From, XAnimate.To and XAnimate.By can be used with double values that set the transition progress the specific amount of time.

    See Also:
        `API XTransitionFilter <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1animations_1_1XTransitionFilter.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.animations.XTransitionFilter']

    @property
    def Direction(self) -> bool:
        """
        This specifies the direction the transition will run.
        
        The legal values are TRUE for forward and FALSE for reverse. The default value is TRUE. Note that this does not impact the media being transitioned to, but only affects the geometry of the transition. Transitions which do not have a reverse interpretation should ignore the direction attribute and assume the default value of TRUE.
        """

    @property
    def FadeColor(self) -> int:
        """
        If the value of the Type attribute is TransitionType.FADE and the value of the Subtype attribute is TransitionSubType.FADETOCOLOR or TransitionSubType.FADEFROMCOLOR, then this attribute specifies the starting or ending color of the fade.
        
        The default value is 0 (black).
        """

    @property
    def Mode(self) -> bool:
        """
        Indicates whether the transitionFilter's parent element will transition in or out.
        
        Legal values are TRUE indicating that the parent media will become more visible as the transition progress increases and FALSE indicating that the parent media will become less visible as the transition progress increases.
        
        The default value is TRUE.
        """

    @property
    def Subtype(self) -> int:
        """
        This is the subtype of the transition.
        
        This must be one of the transition subtypes appropriate for the specified Type as listed in TransitionSubType. TransitionSubType.DEFAULT is the default.
        """

    @property
    def Transition(self) -> int:
        """
        This is the type or family of transition.
        
        This attribute is required and must be one of the transition families listed in TransitionType.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.configuration
from .x_template_container import XTemplateContainer as XTemplateContainer_928f11b7
from ..container.x_container import XContainer as XContainer_d6fb0cc6
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6
from ..util.x_string_escape import XStringEscape as XStringEscape_bd090be6

class SimpleSetAccess(XTemplateContainer_928f11b7, XContainer_d6fb0cc6, XNameAccess_e2ab0cf6, XStringEscape_bd090be6):
    """
    Service Class

    provides access to a dynamic, homogeneous, nonhierarchical set of values or objects.
    
    Also provides information about the template for elements. Allows normalizing externally generated names.
    
    Sets are dynamic containers.
    
    The number and names of contained elements is not fixed in advance, but all elements have to be of one predetermined type.

    See Also:
        `API SimpleSetAccess <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1configuration_1_1SimpleSetAccess.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.script
from typing_extensions import Literal
import typing
from .x_event_attacher import XEventAttacher as XEventAttacher_e3780d23
if typing.TYPE_CHECKING:
    from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
    from .event_listener import EventListener as EventListener_d7890ce5
    from ..uno.x_interface import XInterface as XInterface_8f010a43

class XEventAttacher2(XEventAttacher_e3780d23):
    """

    See Also:
        `API XEventAttacher2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1script_1_1XEventAttacher2.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.script.XEventAttacher2']

    def attachMultipleEventListeners(self, xTarget: 'XInterface_8f010a43', aListeners: 'typing.Tuple[EventListener_d7890ce5, ...]') -> 'typing.Tuple[XEventListener_c7230c4a, ...]':
        """
        Register a multiple set of listeners listening for the same target.
        
        Besides passing multiple listeners, the behavior of this method is identical to that of attachSingleEventListener().

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.beans.IntrospectionException: ``IntrospectionException``
            com.sun.star.script.CannotCreateAdapterException: ``CannotCreateAdapterException``
            com.sun.star.lang.ServiceNotRegisteredException: ``ServiceNotRegisteredException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.util
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing


class DateTimeRange(object):
    """
    Struct Class

    represents a range of date+time values.
    
    **since**
    
        LibreOffice 4.1

    See Also:
        `API DateTimeRange <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1util_1_1DateTimeRange.html>`_
    """
    typeName: Literal['com.sun.star.util.DateTimeRange']

    def __init__(self, StartNanoSeconds: typing.Optional[int] = ..., StartSeconds: typing.Optional[int] = ..., StartMinutes: typing.Optional[int] = ..., StartHours: typing.Optional[int] = ..., StartDay: typing.Optional[int] = ..., StartMonth: typing.Optional[int] = ..., StartYear: typing.Optional[int] = ..., EndNanoSeconds: typing.Optional[int] = ..., EndSeconds: typing.Optional[int] = ..., EndMinutes: typing.Optional[int] = ..., EndHours: typing.Optional[int] = ..., EndDay: typing.Optional[int] = ..., EndMonth: typing.Optional[int] = ..., EndYear: typing.Optional[int] = ..., IsUTC: typing.Optional[bool] = ...) -> None:
        """
        Constructor

        Arguments:
            StartNanoSeconds (int, optional): StartNanoSeconds value.
            StartSeconds (int, optional): StartSeconds value.
            StartMinutes (int, optional): StartMinutes value.
            StartHours (int, optional): StartHours value.
            StartDay (int, optional): StartDay value.
            StartMonth (int, optional): StartMonth value.
            StartYear (int, optional): StartYear value.
            EndNanoSeconds (int, optional): EndNanoSeconds value.
            EndSeconds (int, optional): EndSeconds value.
            EndMinutes (int, optional): EndMinutes value.
            EndHours (int, optional): EndHours value.
            EndDay (int, optional): EndDay value.
            EndMonth (int, optional): EndMonth value.
            EndYear (int, optional): EndYear value.
            IsUTC (bool, optional): IsUTC value.
        """


    @property
    def StartNanoSeconds(self) -> int:
        """
        contains the start nanoseconds (0 - 999 999 999) for the range.
        """


    @property
    def StartSeconds(self) -> int:
        """
        contains the start seconds (0-59) for the range.
        """


    @property
    def StartMinutes(self) -> int:
        """
        contains the start minutes (0-59) for the range.
        """


    @property
    def StartHours(self) -> int:
        """
        contains the start hour (0-23) for the range.
        """


    @property
    def StartDay(self) -> int:
        """
        contains the start day of month (1-31 or 0 for a void date) for the range.
        """


    @property
    def StartMonth(self) -> int:
        """
        contains the start month of year (1-12 or 0 for a void date) for the range.
        """


    @property
    def StartYear(self) -> int:
        """
        contains the start year for the range.
        """


    @property
    def EndNanoSeconds(self) -> int:
        """
        contains the end nanoseconds (0 - 999 999 999) for the range.
        """


    @property
    def EndSeconds(self) -> int:
        """
        contains the end seconds (0-59) for the range.
        """


    @property
    def EndMinutes(self) -> int:
        """
        contains the end minutes (0-59) for the range.
        """


    @property
    def EndHours(self) -> int:
        """
        contains the end hour (0-23) for the range.
        """


    @property
    def EndDay(self) -> int:
        """
        contains the end day of month (1-31 or 0 for a void date) for the range.
        """


    @property
    def EndMonth(self) -> int:
        """
        contains the end month of year (1-12 or 0 for a void date) for the range.
        """


    @property
    def EndYear(self) -> int:
        """
        contains the end year for the range.
        """


    @property
    def IsUTC(self) -> bool:
        """
        true: time zone is UTC false: unknown time zone.
        
        **since**
        
            LibreOffice 4.1
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdbc
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from .driver_property_info import DriverPropertyInfo as DriverPropertyInfo_fd970e01
    from .x_connection import XConnection as XConnection_a36a0b0c

class XDriver(XInterface_8f010a43):
    """
    is the interface that every driver class must implement.
    
    Each driver should supply a service that implements the Driver interface.
    
    The DriverManager will try to load as many drivers as it can find, and then for any given connection request, it will ask each driver in turn to try to connect to the target URL.
    
    It is strongly recommended that each Driver object should be small and standalone so that the Driver object can be loaded and queried without bringing in vast quantities of supporting code.

    See Also:
        `API XDriver <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdbc_1_1XDriver.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sdbc.XDriver']

    def acceptsURL(self, url: str) -> bool:
        """
        returns TRUE if the driver thinks that it can open a connection to the given URL.
        
        Typically drivers will return TRUE if they understand the subprotocol specified in the URL and FALSE if they do not.

        Raises:
            SQLException: ``SQLException``
        """
    def connect(self, url: str, info: 'typing.Tuple[PropertyValue_c9610c73, ...]') -> 'XConnection_a36a0b0c':
        """
        attempts to make a database connection to the given URL.
        
        The driver should return NULL if it realizes it is the wrong kind of driver to connect to the given URL. This will be common, as when the driver manager is asked to connect to a given URL it passes the URL to each loaded driver in turn.
        
        The driver should raise a com.sun.star.sdbc.SQLException if it is the right driver to connect to the given URL, but has trouble connecting to the database.
        
        The info argument can be used to pass arbitrary string tag/value pairs as connection arguments. Normally at least \"user\" and \"password\" properties should be included in the Properties. For a JDBC driver also the Java class must be supplied in the property named JavaDriverClass, and a class path (a space-separated list of URLs) needed to locate that class can optionally be supplied in a property named JavaDriverClassPath. Possible property value names are when supported by the driver:

        Raises:
            SQLException: ``SQLException``
        """
    def getMajorVersion(self) -> int:
        """
        gets the driver's major version number.
        
        Initially this should be 1.
        """
    def getMinorVersion(self) -> int:
        """
        gets the driver's minor version number.
        
        Initially this should be 0.
        """
    def getPropertyInfo(self, url: str, info: 'typing.Tuple[PropertyValue_c9610c73, ...]') -> 'typing.Tuple[DriverPropertyInfo_fd970e01, ...]':
        """
        gets information about the possible properties for this driver.
        
        The getPropertyInfo method is intended to allow a generic GUI tool to discover what properties it should prompt a human for in order to get enough information to connect to a database. Note that depending on the values the human has supplied so far, additional values may become necessary, so it may be necessary to iterate though several calls to getPropertyInfo.

        Raises:
            SQLException: ``SQLException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.bridge.oleautomation
from ..x_bridge_supplier2 import XBridgeSupplier2 as XBridgeSupplier2_fb800da0

class BridgeSupplier(XBridgeSupplier2_fb800da0):
    """
    Service Class

    maps UNO types to oleautomation types and vice versa.
    
    The function com.sun.star.bridge.XBridgeSupplier2.createBridge() maps a value of a UNO or Automation type to the desired target type. If a UNO interface was mapped to IDispatch, then all objects (interfaces, structs) and other types which are obtained from that Automation object are automatically mapped to the corresponding Automation types. Hence, if one provides an initial object which forms the root of all other objects, such as a service manager, then only that object needs to be explicitly mapped by a call to com.sun.star.bridge.XBridgeSupplier2.createBridge(). The same holds true if an automation object is mapped to a UNO interface.
    
    For Automation objects to be mapped they have to implement IDispatch interface. Other COM interfaces, except for IUnknown, are not supported. UNO interfaces and structs are mapped to IDispatch.
    
    The service implements the com.sun.star.bridge.XBridgeSupplier2 interface and handles the model types com.sun.star.bridge.ModelDependent.UNO and com.sun.star.bridge.ModelDependent.OLE. The service does not specify any requirements for registering OLE objects and class factories.

    See Also:
        `API BridgeSupplier <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1bridge_1_1oleautomation_1_1BridgeSupplier.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.xml
from ..container.x_name_container import XNameContainer as XNameContainer_cb90e47

class AttributeContainer(XNameContainer_cb90e47):
    """
    Service Class

    This service describes a container for XML attributes.
    
    Each attribute is accessed with its local name, or optionally, its local name with its namespace prefix. The type and value of an attribute is stored in a AttributeData struct. If you use a namespace in the AttributeData, you must use a prefix in the name and you must use a namespace, if you use a prefix.

    See Also:
        `API AttributeContainer <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1xml_1_1AttributeContainer.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.text
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing


class TextColumn(object):
    """
    Struct Class

    defines a single text column.

    See Also:
        `API TextColumn <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1text_1_1TextColumn.html>`_
    """
    typeName: Literal['com.sun.star.text.TextColumn']

    def __init__(self, Width: typing.Optional[int] = ..., LeftMargin: typing.Optional[int] = ..., RightMargin: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            Width (int, optional): Width value.
            LeftMargin (int, optional): LeftMargin value.
            RightMargin (int, optional): RightMargin value.
        """


    @property
    def Width(self) -> int:
        """
        contains the relative width of the column, including both margins.
        
        Width isn't a metric value, it's a relative value to the sum of the width of all columns.
        """


    @property
    def LeftMargin(self) -> int:
        """
        contains the left margin of the column.
        
        This is a metric value.
        """


    @property
    def RightMargin(self) -> int:
        """
        contains the right margin of the column.
        
        This is a metric value.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .menu_item_type import MenuItemType as MenuItemType_a4760b1a
    from .x_menu_listener import XMenuListener as XMenuListener_af9e0b87
    from .x_popup_menu import XPopupMenu as XPopupMenu_8ee90a55

class XMenu(XInterface_8f010a43):
    """
    specifies a simple menu.

    See Also:
        `API XMenu <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XMenu.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.XMenu']

    def addMenuListener(self, xListener: 'XMenuListener_af9e0b87') -> None:
        """
        adds the specified menu listener to receive events from this menu.
        """
    def clear(self) -> None:
        """
        removes all items from the menu.
        """
    def enableAutoMnemonics(self, bEnable: bool) -> None:
        """
        specifies whether mnemonics are automatically assigned to menu items, or not.
        """
    def enableItem(self, nItemId: int, bEnable: bool) -> None:
        """
        enables or disables the menu item.
        """
    def getCommand(self, nItemId: int) -> str:
        """
        retrieves the command string for the menu item.
        """
    def getHelpCommand(self, nItemId: int) -> str:
        """
        retrieves the help command string for the menu item.
        """
    def getHelpText(self, nItemId: int) -> str:
        """
        retrieves the help text for the menu item.
        """
    def getItemCount(self) -> int:
        """
        returns the number of items in the menu.
        """
    def getItemId(self, nItemPos: int) -> int:
        """
        returns the ID of the item at the specified position.
        """
    def getItemPos(self, nItemId: int) -> int:
        """
        returns the position of the item with the specified ID.
        """
    def getItemText(self, nItemId: int) -> str:
        """
        returns the string for the given item id.
        """
    def getItemType(self, nItemPos: int) -> 'MenuItemType_a4760b1a':
        """
        retrieves the type of the menu item.
        """
    def getPopupMenu(self, nItemId: int) -> 'XPopupMenu_8ee90a55':
        """
        returns the popup menu from the menu item.
        """
    def getTipHelpText(self, nItemId: int) -> str:
        """
        retrieves the tip help text for the menu item.
        """
    def hideDisabledEntries(self, bHide: bool) -> None:
        """
        specifies whether disabled menu entries should be hidden, or not.
        """
    def insertItem(self, nItemId: int, aText: str, nItemStyle: int, nItemPos: int) -> None:
        """
        inserts an item into the menu.
        
        The item is appended if the position is greater than or equal to getItemCount() or if it is negative.
        """
    def isItemEnabled(self, nItemId: int) -> bool:
        """
        returns the state of the menu item.
        """
    def isPopupMenu(self) -> bool:
        """
        checks whether an XMenu is an XPopupMenu.
        """
    def removeItem(self, nItemPos: int, nCount: int) -> None:
        """
        removes one or more items from the menu.
        """
    def removeMenuListener(self, xListener: 'XMenuListener_af9e0b87') -> None:
        """
        removes the specified menu listener so that it no longer receives events from this menu.
        """
    def setCommand(self, nItemId: int, aCommand: str) -> None:
        """
        sets the command string for the menu item.
        """
    def setHelpCommand(self, nItemId: int, aCommand: str) -> None:
        """
        sets the help command string for the menu item.
        """
    def setHelpText(self, nItemId: int, sHelpText: str) -> None:
        """
        sets the help text for the menu item.
        """
    def setItemText(self, nItemId: int, aText: str) -> None:
        """
        sets the text for the menu item.
        """
    def setPopupMenu(self, nItemId: int, aPopupMenu: 'XPopupMenu_8ee90a55') -> None:
        """
        sets the popup menu for a specified menu item.
        """
    def setTipHelpText(self, nItemId: int, sTipHelpText: str) -> None:
        """
        sets the tip help text for the menu item.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.animations
from typing_extensions import Literal
from .x_animate import XAnimate as XAnimate_ca680c52

class XAnimateColor(XAnimate_ca680c52):
    """
    Interface for animation by defining color changes over time.
    
    Only color value will be legal values for the following members

    See Also:
        `API XAnimateColor <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1animations_1_1XAnimateColor.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.animations.XAnimateColor']

    @property
    def ColorInterpolation(self) -> int:
        """
        defines the color space which is used to perform the interpolation.
        """

    @property
    def Direction(self) -> bool:
        """
        defines the direction which is used to perform the interpolation inside the color space defined with ColorInterpolation.
        
        Values could be TRUE for clockwise and FALSE for counterclockwise.
        
        This attribute will be ignored for color spaces where this does not make any sense.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.datatransfer.dnd
# Libre Office Version: 7.2
from typing_extensions import Literal
from .drag_source_event import DragSourceEvent as DragSourceEvent_8ccf115c
from ...uno.x_interface import XInterface as XInterface_8f010a43
from .x_drag_source_context import XDragSourceContext as XDragSourceContext_c2661297
from .x_drag_source import XDragSource as XDragSource_49900fb2
import typing


class DragSourceDragEvent(DragSourceEvent_8ccf115c):
    """
    Struct Class

    The DragSourceDragEvent is delivered from an object that implements the XDragSourceContext to the currently registered drag source listener.
    
    It contains state regarding the current state of the operation to enable the operations initiator to provide the end user with the appropriate drag over feedback.

    See Also:
        `API DragSourceDragEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1DragSourceDragEvent.html>`_
    """
    typeName: Literal['com.sun.star.datatransfer.dnd.DragSourceDragEvent']

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = ..., DragSourceContext: typing.Optional[XDragSourceContext_c2661297] = ..., DragSource: typing.Optional[XDragSource_49900fb2] = ..., DropAction: typing.Optional[int] = ..., UserAction: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            DragSourceContext (XDragSourceContext, optional): DragSourceContext value.
            DragSource (XDragSource, optional): DragSource value.
            DropAction (int, optional): DropAction value.
            UserAction (int, optional): UserAction value.
        """


    @property
    def DropAction(self) -> int:
        """
        The drag action selected by the current drop target.
        """


    @property
    def UserAction(self) -> int:
        """
        The user's currently selected drop action.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.media
# Libre Office Version: 7.2
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum

ENUM ZoomLevel

See Also:
    `API ZoomLevel <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1media.html#aa2569917c2883c1d1c0c0ee02e671ac6>`_
"""

FIT_TO_WINDOW: 'uno.Enum'
"""
specifies that the video should be zoomed to window size
"""
FIT_TO_WINDOW_FIXED_ASPECT: 'uno.Enum'
"""
specifies that the video should be zoomed to window size with using a fixed aspect ratio
"""
FULLSCREEN: 'uno.Enum'
"""
specifies that the video should be displayed in fullscreen mode, if available
"""
NOT_AVAILABLE: 'uno.Enum'
"""
specifies that the video window itself is not available at all, e.g.

in cases of pure audio playback
"""
ORIGINAL: 'uno.Enum'
"""
specifies that the video should be displayed with its original size
"""
ZOOM_1_TO_2: 'uno.Enum'
"""
specifies that the video should be zoomed to a factor of 1:2
"""
ZOOM_1_TO_4: 'uno.Enum'
"""
specifies that the video should be zoomed to a factor of 1:4
"""
ZOOM_2_TO_1: 'uno.Enum'
"""
specifies that the video should be zoomed to a factor of 2:1
"""
ZOOM_4_TO_1: 'uno.Enum'
"""
specifies that the video should be zoomed to a factor of 4:1
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.util
from typing_extensions import Literal


class NumberFormat(object):
    """
    Const

    contains constants that are used to specify the type of a number format.

    See Also:
        `API NumberFormat <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1util_1_1NumberFormat.html>`_
    """
    ALL: Literal[0]
    """
    selects all number formats.
    """
    DEFINED: Literal[1]
    """
    selects only user-defined number formats.
    """
    DATE: Literal[2]
    """
    selects date formats.
    """
    TIME: Literal[4]
    """
    selects time formats.
    """
    CURRENCY: Literal[8]
    """
    selects currency formats.
    """
    NUMBER: Literal[16]
    """
    selects decimal number formats.
    """
    SCIENTIFIC: Literal[32]
    """
    selects scientific number formats.
    """
    FRACTION: Literal[64]
    """
    selects number formats for fractions.
    """
    PERCENT: Literal[128]
    """
    selects percentage number formats.
    """
    TEXT: Literal[256]
    """
    selects text number formats.
    """
    DATETIME: Literal[6]
    """
    selects number formats which contain date and time.
    """
    LOGICAL: Literal[1024]
    """
    selects boolean number formats.
    """
    UNDEFINED: Literal[2048]
    """
    is used as a return value if no format exists.
    """
    EMPTY: Literal[4096]
    DURATION: Literal[8196]




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.util
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from .date_time import DateTime as DateTime_84de09d3


class DateTimeWithTimezone(object):
    """
    Struct Class

    represents a combined date+time value with time zone.
    
    **since**
    
        LibreOffice 4.1

    See Also:
        `API DateTimeWithTimezone <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1util_1_1DateTimeWithTimezone.html>`_
    """
    typeName: Literal['com.sun.star.util.DateTimeWithTimezone']

    def __init__(self, DateTimeInTZ: typing.Optional[DateTime_84de09d3] = ..., Timezone: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            DateTimeInTZ (DateTime, optional): DateTimeInTZ value.
            Timezone (int, optional): Timezone value.
        """


    @property
    def DateTimeInTZ(self) -> DateTime_84de09d3:
        """
        the date and time (in TimeZone)
        """


    @property
    def Timezone(self) -> int:
        """
        contains the time zone, as signed offset in minutes from UTC, that is east of UTC, that is the amount of minutes that should be added to UTC time to obtain the time in that timezone.
        
        To obtain UTC datetime from DateTimeInTZ, you need to subtract TimeZone minutes.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.text
import typing
from ..drawing.shape import Shape as Shape_85cc09e5
if typing.TYPE_CHECKING:
    from ..awt.point import Point as Point_5fb2085e
    from ..drawing.homogen_matrix3 import HomogenMatrix3 as HomogenMatrix3_f0fb0d69
    from .text_content_anchor_type import TextContentAnchorType as TextContentAnchorType_2cbe0f4a
    from .wrap_text_mode import WrapTextMode as WrapTextMode_b1dd0b91
    from .x_text_frame import XTextFrame as XTextFrame_9a7e0ab5
    from .x_text_range import XTextRange as XTextRange_9a910ab7

class Shape(Shape_85cc09e5):
    """
    Service Class

    specifies the service of shapes in a text document
    
    **since**
    
        LibreOffice 6.4

    See Also:
        `API Shape <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1Shape.html>`_
    """
    @property
    def AllowOverlap(self) -> bool:
        """
        This defines if the shape is allowed to overlap with other anchored objects.
        
        **since**
        
            LibreOffice 6.4
        """
    @property
    def AnchorFrame(self) -> 'XTextFrame_9a7e0ab5':
        """
        contains the text frame the current frame is anchored to.
        
        The value is valid only if the AnchorType is TextContentAnchorType.AT_FRAME.
        """
    @property
    def AnchorPageNo(self) -> int:
        """
        contains the number of the page where the objects are anchored.
        
        The value is valid only if the AnchorType is TextContentAnchorType.AT_PAGE.
        """
    @property
    def AnchorType(self) -> 'TextContentAnchorType_2cbe0f4a':
        """
        specifies how the text content is attached to its surrounding Text.
        """
    @property
    def BottomMargin(self) -> int:
        """
        contains the bottom margin of the object.
        """
    @property
    def ContourOutside(self) -> bool:
        """
        the text flows only around the contour of the object.
        """
    @property
    def EndPositionInHoriL2R(self) -> 'Point_5fb2085e':
        """
        determines the end position of the shape in horizontal left-to-right layout
        
        This property is needed for the export of the OASIS Open Office file format to the OpenOffice.org file format. It provides the end position property of the included service com.sun.star.drawing.Shape converted to the horizontal left-to-right layout.
        
        **since**
        
            OOo 2.0
        """
    @property
    def HoriOrient(self) -> int:
        """
        determines the horizontal orientation of the object.
        """
    @property
    def HoriOrientPosition(self) -> int:
        """
        contains the horizontal position of the object (1/100 mm).
        
        It is only valid if \"HoriOrient\" is HoriOrientation_NONE.
        """
    @property
    def HoriOrientRelation(self) -> int:
        """
        determines the environment of the object to which the orientation is related.
        """
    @property
    def LeftMargin(self) -> int:
        """
        contains the left margin of the object.
        """
    @property
    def Opaque(self) -> bool:
        """
        determines if the object is opaque or transparent for text.
        """
    @property
    def PositionLayoutDir(self) -> int:
        """
        determines layout direction the position attributes of the shape is given
        
        Valid values are given by PositionLayoutDir
        
        **since**
        
            OOo 2.0
        """
    @property
    def RightMargin(self) -> int:
        """
        contains the right margin of the object.
        """
    @property
    def StartPositionInHoriL2R(self) -> 'Point_5fb2085e':
        """
        determines the start position of the shape in horizontal left-to-right layout
        
        This property is needed for the export of the OASIS Open Office file format to the OpenOffice.org file format. It provides the start position property of the included service com.sun.star.drawing.Shape converted to the horizontal left-to-right layout.
        
        **since**
        
            OOo 2.0
        """
    @property
    def Surround(self) -> 'WrapTextMode_b1dd0b91':
        """
        determines the type of the surrounding text.
        """
    @property
    def SurroundAnchorOnly(self) -> bool:
        """
        determines if the text of the paragraph in which the object is anchored, wraps around the object.
        """
    @property
    def SurroundContour(self) -> bool:
        """
        determines if the text wraps around the contour of the object.
        """
    @property
    def TextRange(self) -> 'XTextRange_9a910ab7':
        """
        contains a text range where the shape should be anchored to.
        
        There are two different ways to get newly created shapes into the text document. One of them is to use the insertTextContent() method of the com.sun.star.text.XSimpleText. The other is to call the add() method of the com.sun.star.drawing.XShapes interface. To be able to determine an anchor position for shape that are anchored at a certain text position the property TextRange is used.
        
        This property is used when the shape gets inserted/added and becomes invalid after that.
        """
    @property
    def TopMargin(self) -> int:
        """
        contains the top margin of the object.
        """
    @property
    def TransformationInHoriL2R(self) -> 'HomogenMatrix3_f0fb0d69':
        """
        determines the transformation of the shape in horizontal left-to-right layout
        
        This property is needed for the export of the OASIS Open Office file format to the OpenOffice.org file format. It provides the transformation property of the included service com.sun.star.drawing.Shape converted to the horizontal left-to-right layout.
        
        **since**
        
            OOo 2.0
        """
    @property
    def VertOrient(self) -> int:
        """
        determines the vertical orientation of the object.
        """
    @property
    def VertOrientPosition(self) -> int:
        """
        contains the vertical position of the object (1/100 mm).
        
        It is only valid if TextEmbeddedObject.VertOrient is VertOrientation.NONE.
        """
    @property
    def VertOrientRelation(self) -> int:
        """
        determines the environment of the object to which the orientation is related.
        """
    @property
    def WrapInfluenceOnPosition(self) -> int:
        """
        determines the influence of the text wrap on the positioning of the shape
        
        The value of this property is only evaluated for the positioning of the shape, if the text document setting ConsiderTextWrapOnObjPos is TRUE. Valid values are given by WrapInfluenceOnPosition
        
        **since**
        
            OOo 2.0
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.view
from abc import ABC

class PrintSettings(ABC):
    """
    Service Class

    provides access to the settings for printing documents.
    
    These settings are printer independent but affect the rendering of the document.

    See Also:
        `API PrintSettings <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1view_1_1PrintSettings.html>`_
    """
    @property
    def PrintAnnotationMode(self) -> int:
        """
        determines how annotations are printed.
        """
    @property
    def PrintBlackFonts(self) -> bool:
        """
        If TRUE, all characters are printed in black.
        
        It is useful for printing colored text on a b/w printer.
        """
    @property
    def PrintControls(self) -> bool:
        """
        If TRUE, control shapes are included in printing.
        """
    @property
    def PrintDrawings(self) -> bool:
        """
        If TRUE, drawing objects (shapes) are included in printing.
        """
    @property
    def PrintGraphics(self) -> bool:
        """
        If TRUE, graphic objects are included in printing.
        """
    @property
    def PrintLeftPages(self) -> bool:
        """
        If TRUE, left pages are included in printing.
        """
    @property
    def PrintPageBackground(self) -> bool:
        """
        If TRUE, the background of the page is printed.
        """
    @property
    def PrintProspect(self) -> bool:
        """
        If TRUE, the pages are printed in the order of prospects.
        """
    @property
    def PrintReversed(self) -> bool:
        """
        If TRUE, the pages are printed in reverse order.
        
        The last page is printed first.
        """
    @property
    def PrintRightPages(self) -> bool:
        """
        If TRUE, right pages are included in printing.
        """
    @property
    def PrintTables(self) -> bool:
        """
        If TRUE, tables are included in printing.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdb.tools
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from ...container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6
    from ...lang.x_component import XComponent as XComponent_98dc0ab5
    from ..x_single_select_query_composer import XSingleSelectQueryComposer as XSingleSelectQueryComposer_66e310b9
    from .x_data_source_meta_data import XDataSourceMetaData as XDataSourceMetaData_547c0fe4
    from .x_object_names import XObjectNames as XObjectNames_ed550d43
    from .x_table_name import XTableName as XTableName_d3140c61

class XConnectionTools(ABC):
    """
    encapsulates various useful functionality around a com.sun.star.sdb.Connection
    
    Most of the functionality provided here is meaningful only relative to a given database connection. For instance, for quoting table names, you need the meta data instance of the connection. Thus, the entry point for obtaining a XConnectionTools instance is the com.sun.star.sdb.Connection service.
    
    Note that nearly all functionality provided by this interface is also available by other means, it's only provided here for convenience purposes.
    
    **since**
    
        OOo 2.0.4

    See Also:
        `API XConnectionTools <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdb_1_1tools_1_1XConnectionTools.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sdb.tools.XConnectionTools']

    def createTableName(self) -> 'XTableName_d3140c61':
        """
        creates an instance supporting the XTableName interface, which can be used to manipulate table names for various purposes.
        
        The returned object is guaranteed to not be NULL.
        """
    def getComposer(self, commandType: int, command: str) -> 'XSingleSelectQueryComposer_66e310b9':
        """
        get the composer initialized with a command and command type.
        """
    def getDataSourceMetaData(self) -> 'XDataSourceMetaData_547c0fe4':
        """
        provides access to the application-level data source meta data
        """
    def getFieldsByCommandDescriptor(self, commandType: int, command: str, keepFieldsAlive: 'XComponent_98dc0ab5') -> 'XNameAccess_e2ab0cf6':
        """
        get fields for a result set given by a \"command descriptor\"
        
        A command descriptor here means:

        * ``keepFieldsAlive`` is an out direction argument.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def getObjectNames(self) -> 'XObjectNames_ed550d43':
        """
        returns an instance supporting the XObjectNames interface, which provides access to functionality around table and query names.
        
        The returned object is guaranteed to not be NULL.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .._pyi.text.accessible_endnote_view import AccessibleEndnoteView as AccessibleEndnoteView
from .._pyi.text.accessible_footnote_view import AccessibleFootnoteView as AccessibleFootnoteView
from .._pyi.text.accessible_header_footer_view import AccessibleHeaderFooterView as AccessibleHeaderFooterView
from .._pyi.text.accessible_page_view import AccessiblePageView as AccessiblePageView
from .._pyi.text.accessible_paragraph_view import AccessibleParagraphView as AccessibleParagraphView
from .._pyi.text.accessible_text_document_page_view import AccessibleTextDocumentPageView as AccessibleTextDocumentPageView
from .._pyi.text.accessible_text_document_view import AccessibleTextDocumentView as AccessibleTextDocumentView
from .._pyi.text.accessible_text_embedded_object import AccessibleTextEmbeddedObject as AccessibleTextEmbeddedObject
from .._pyi.text.accessible_text_frame_view import AccessibleTextFrameView as AccessibleTextFrameView
from .._pyi.text.accessible_text_graphic_object import AccessibleTextGraphicObject as AccessibleTextGraphicObject
from .._pyi.text.auto_text_container import AutoTextContainer as AutoTextContainer
from .._pyi.text.auto_text_entry import AutoTextEntry as AutoTextEntry
from .._pyi.text.auto_text_group import AutoTextGroup as AutoTextGroup
from .._pyi.text.base_frame import BaseFrame as BaseFrame
from .._pyi.text.base_frame_properties import BaseFrameProperties as BaseFrameProperties
from .._pyi.text.base_index import BaseIndex as BaseIndex
from .._pyi.text.base_index_mark import BaseIndexMark as BaseIndexMark
from .._pyi.text.bibliography import Bibliography as Bibliography
from .._pyi.text.bookmark import Bookmark as Bookmark
from .._pyi.text.bookmarks import Bookmarks as Bookmarks
from .._pyi.text.cell import Cell as Cell
from .._pyi.text.cell_properties import CellProperties as CellProperties
from .._pyi.text.cell_range import CellRange as CellRange
from .._pyi.text.chained_text_frame import ChainedTextFrame as ChainedTextFrame
from .._pyi.text.chapter_numbering_rule import ChapterNumberingRule as ChapterNumberingRule
from .._pyi.text.content_index import ContentIndex as ContentIndex
from .._pyi.text.content_index_mark import ContentIndexMark as ContentIndexMark
from .._pyi.text.default_numbering_provider import DefaultNumberingProvider as DefaultNumberingProvider
from .._pyi.text.defaults import Defaults as Defaults
from .._pyi.text.dependent_text_field import DependentTextField as DependentTextField
from .._pyi.text.document_index import DocumentIndex as DocumentIndex
from .._pyi.text.document_index_level_format import DocumentIndexLevelFormat as DocumentIndexLevelFormat
from .._pyi.text.document_index_mark import DocumentIndexMark as DocumentIndexMark
from .._pyi.text.document_index_mark_asian import DocumentIndexMarkAsian as DocumentIndexMarkAsian
from .._pyi.text.document_index_paragraph_styles import DocumentIndexParagraphStyles as DocumentIndexParagraphStyles
from .._pyi.text.document_indexes import DocumentIndexes as DocumentIndexes
from .._pyi.text.document_settings import DocumentSettings as DocumentSettings
from .._pyi.text.endnote import Endnote as Endnote
from .._pyi.text.endnote_settings import EndnoteSettings as EndnoteSettings
from .._pyi.text.footnote import Footnote as Footnote
from .._pyi.text.footnote_settings import FootnoteSettings as FootnoteSettings
from .._pyi.text.footnotes import Footnotes as Footnotes
from .._pyi.text.generic_text_document import GenericTextDocument as GenericTextDocument
from .._pyi.text.global_document import GlobalDocument as GlobalDocument
from .._pyi.text.global_settings import GlobalSettings as GlobalSettings
from .._pyi.text.graphic_crop import GraphicCrop as GraphicCrop
from .._pyi.text.hori_orientation_format import HoriOrientationFormat as HoriOrientationFormat
from .._pyi.text.illustrations_index import IllustrationsIndex as IllustrationsIndex
from .._pyi.text.in_content_metadata import InContentMetadata as InContentMetadata
from .._pyi.text.invalid_text_content_exception import InvalidTextContentException as InvalidTextContentException
from .._pyi.text.line_numbering_properties import LineNumberingProperties as LineNumberingProperties
from .._pyi.text.mail_merge import MailMerge as MailMerge
from .._pyi.text.mail_merge_event import MailMergeEvent as MailMergeEvent
from .._pyi.text.module_dispatcher import ModuleDispatcher as ModuleDispatcher
from .._pyi.text.numbering_level import NumberingLevel as NumberingLevel
from .._pyi.text.numbering_rules import NumberingRules as NumberingRules
from .._pyi.text.numbering_style import NumberingStyle as NumberingStyle
from .._pyi.text.object_index import ObjectIndex as ObjectIndex
from .._pyi.text.page_footnote_info import PageFootnoteInfo as PageFootnoteInfo
from .._pyi.text.page_print_settings import PagePrintSettings as PagePrintSettings
from .._pyi.text.paragraph import Paragraph as Paragraph
from .._pyi.text.paragraph_enumeration import ParagraphEnumeration as ParagraphEnumeration
from .._pyi.text.print_settings import PrintSettings as PrintSettings
from .._pyi.text.redline_portion import RedlinePortion as RedlinePortion
from .._pyi.text.reference_mark import ReferenceMark as ReferenceMark
from .._pyi.text.reference_marks import ReferenceMarks as ReferenceMarks
from .._pyi.text.section_file_link import SectionFileLink as SectionFileLink
from .._pyi.text.shape import Shape as Shape
from .._pyi.text.table_column_separator import TableColumnSeparator as TableColumnSeparator
from .._pyi.text.table_columns import TableColumns as TableColumns
from .._pyi.text.table_index import TableIndex as TableIndex
from .._pyi.text.table_rows import TableRows as TableRows
from .._pyi.text.text import Text as Text
from .._pyi.text.text_column import TextColumn as TextColumn
from .._pyi.text.text_column_sequence import TextColumnSequence as TextColumnSequence
from .._pyi.text.text_columns import TextColumns as TextColumns
from .._pyi.text.text_content import TextContent as TextContent
from .._pyi.text.text_content_collection import TextContentCollection as TextContentCollection
from .._pyi.text.text_cursor import TextCursor as TextCursor
from .._pyi.text.text_document import TextDocument as TextDocument
from .._pyi.text.text_document_view import TextDocumentView as TextDocumentView
from .._pyi.text.text_embedded_object import TextEmbeddedObject as TextEmbeddedObject
from .._pyi.text.text_embedded_objects import TextEmbeddedObjects as TextEmbeddedObjects
from .._pyi.text.text_field import TextField as TextField
from .._pyi.text.text_field_enumeration import TextFieldEnumeration as TextFieldEnumeration
from .._pyi.text.text_field_master import TextFieldMaster as TextFieldMaster
from .._pyi.text.text_field_masters import TextFieldMasters as TextFieldMasters
from .._pyi.text.text_fields import TextFields as TextFields
from .._pyi.text.text_frame import TextFrame as TextFrame
from .._pyi.text.text_frames import TextFrames as TextFrames
from .._pyi.text.text_graphic_object import TextGraphicObject as TextGraphicObject
from .._pyi.text.text_graphic_objects import TextGraphicObjects as TextGraphicObjects
from .._pyi.text.text_layout_cursor import TextLayoutCursor as TextLayoutCursor
from .._pyi.text.text_markup_descriptor import TextMarkupDescriptor as TextMarkupDescriptor
from .._pyi.text.text_page_style import TextPageStyle as TextPageStyle
from .._pyi.text.text_portion import TextPortion as TextPortion
from .._pyi.text.text_portion_enumeration import TextPortionEnumeration as TextPortionEnumeration
from .._pyi.text.text_position import TextPosition as TextPosition
from .._pyi.text.text_range import TextRange as TextRange
from .._pyi.text.text_range_content_properties import TextRangeContentProperties as TextRangeContentProperties
from .._pyi.text.text_range_selection import TextRangeSelection as TextRangeSelection
from .._pyi.text.text_ranges import TextRanges as TextRanges
from .._pyi.text.text_section import TextSection as TextSection
from .._pyi.text.text_sections import TextSections as TextSections
from .._pyi.text.text_sort_descriptor import TextSortDescriptor as TextSortDescriptor
from .._pyi.text.text_sort_descriptor2 import TextSortDescriptor2 as TextSortDescriptor2
from .._pyi.text.text_sortable import TextSortable as TextSortable
from .._pyi.text.text_table import TextTable as TextTable
from .._pyi.text.text_table_cursor import TextTableCursor as TextTableCursor
from .._pyi.text.text_table_row import TextTableRow as TextTableRow
from .._pyi.text.text_tables import TextTables as TextTables
from .._pyi.text.text_view_cursor import TextViewCursor as TextViewCursor
from .._pyi.text.user_defined_index import UserDefinedIndex as UserDefinedIndex
from .._pyi.text.user_index import UserIndex as UserIndex
from .._pyi.text.user_index_mark import UserIndexMark as UserIndexMark
from .._pyi.text.vert_orientation_format import VertOrientationFormat as VertOrientationFormat
from .._pyi.text.view_settings import ViewSettings as ViewSettings
from .._pyi.text.web_document import WebDocument as WebDocument
from .._pyi.text.x_auto_text_container import XAutoTextContainer as XAutoTextContainer
from .._pyi.text.x_auto_text_container2 import XAutoTextContainer2 as XAutoTextContainer2
from .._pyi.text.x_auto_text_entry import XAutoTextEntry as XAutoTextEntry
from .._pyi.text.x_auto_text_group import XAutoTextGroup as XAutoTextGroup
from .._pyi.text.x_bookmark_insert_tool import XBookmarkInsertTool as XBookmarkInsertTool
from .._pyi.text.x_bookmarks_supplier import XBookmarksSupplier as XBookmarksSupplier
from .._pyi.text.x_chapter_numbering_supplier import XChapterNumberingSupplier as XChapterNumberingSupplier
from .._pyi.text.x_default_numbering_provider import XDefaultNumberingProvider as XDefaultNumberingProvider
from .._pyi.text.x_dependent_text_field import XDependentTextField as XDependentTextField
from .._pyi.text.x_document_index import XDocumentIndex as XDocumentIndex
from .._pyi.text.x_document_index_mark import XDocumentIndexMark as XDocumentIndexMark
from .._pyi.text.x_document_indexes_supplier import XDocumentIndexesSupplier as XDocumentIndexesSupplier
from .._pyi.text.x_endnotes_settings_supplier import XEndnotesSettingsSupplier as XEndnotesSettingsSupplier
from .._pyi.text.x_endnotes_supplier import XEndnotesSupplier as XEndnotesSupplier
from .._pyi.text.x_flat_paragraph import XFlatParagraph as XFlatParagraph
from .._pyi.text.x_flat_paragraph_iterator import XFlatParagraphIterator as XFlatParagraphIterator
from .._pyi.text.x_flat_paragraph_iterator_provider import XFlatParagraphIteratorProvider as XFlatParagraphIteratorProvider
from .._pyi.text.x_footnote import XFootnote as XFootnote
from .._pyi.text.x_footnotes_settings_supplier import XFootnotesSettingsSupplier as XFootnotesSettingsSupplier
from .._pyi.text.x_footnotes_supplier import XFootnotesSupplier as XFootnotesSupplier
from .._pyi.text.x_form_field import XFormField as XFormField
from .._pyi.text.x_line_numbering_properties import XLineNumberingProperties as XLineNumberingProperties
from .._pyi.text.x_mail_merge_broadcaster import XMailMergeBroadcaster as XMailMergeBroadcaster
from .._pyi.text.x_mail_merge_listener import XMailMergeListener as XMailMergeListener
from .._pyi.text.x_marking_access import XMarkingAccess as XMarkingAccess
from .._pyi.text.x_multi_text_markup import XMultiTextMarkup as XMultiTextMarkup
from .._pyi.text.x_numbering_formatter import XNumberingFormatter as XNumberingFormatter
from .._pyi.text.x_numbering_rules_supplier import XNumberingRulesSupplier as XNumberingRulesSupplier
from .._pyi.text.x_numbering_type_info import XNumberingTypeInfo as XNumberingTypeInfo
from .._pyi.text.x_page_cursor import XPageCursor as XPageCursor
from .._pyi.text.x_page_printable import XPagePrintable as XPagePrintable
from .._pyi.text.x_paragraph_append import XParagraphAppend as XParagraphAppend
from .._pyi.text.x_paragraph_cursor import XParagraphCursor as XParagraphCursor
from .._pyi.text.x_paste_broadcaster import XPasteBroadcaster as XPasteBroadcaster
from .._pyi.text.x_paste_listener import XPasteListener as XPasteListener
from .._pyi.text.x_redline import XRedline as XRedline
from .._pyi.text.x_reference_marks_supplier import XReferenceMarksSupplier as XReferenceMarksSupplier
from .._pyi.text.x_relative_text_content_insert import XRelativeTextContentInsert as XRelativeTextContentInsert
from .._pyi.text.x_relative_text_content_remove import XRelativeTextContentRemove as XRelativeTextContentRemove
from .._pyi.text.x_ruby_selection import XRubySelection as XRubySelection
from .._pyi.text.x_sentence_cursor import XSentenceCursor as XSentenceCursor
from .._pyi.text.x_simple_text import XSimpleText as XSimpleText
from .._pyi.text.x_text import XText as XText
from .._pyi.text.x_text_append import XTextAppend as XTextAppend
from .._pyi.text.x_text_append_and_convert import XTextAppendAndConvert as XTextAppendAndConvert
from .._pyi.text.x_text_columns import XTextColumns as XTextColumns
from .._pyi.text.x_text_content import XTextContent as XTextContent
from .._pyi.text.x_text_content_append import XTextContentAppend as XTextContentAppend
from .._pyi.text.x_text_convert import XTextConvert as XTextConvert
from .._pyi.text.x_text_copy import XTextCopy as XTextCopy
from .._pyi.text.x_text_cursor import XTextCursor as XTextCursor
from .._pyi.text.x_text_document import XTextDocument as XTextDocument
from .._pyi.text.x_text_embedded_objects_supplier import XTextEmbeddedObjectsSupplier as XTextEmbeddedObjectsSupplier
from .._pyi.text.x_text_field import XTextField as XTextField
from .._pyi.text.x_text_fields_supplier import XTextFieldsSupplier as XTextFieldsSupplier
from .._pyi.text.x_text_frame import XTextFrame as XTextFrame
from .._pyi.text.x_text_frames_supplier import XTextFramesSupplier as XTextFramesSupplier
from .._pyi.text.x_text_graphic_objects_supplier import XTextGraphicObjectsSupplier as XTextGraphicObjectsSupplier
from .._pyi.text.x_text_markup import XTextMarkup as XTextMarkup
from .._pyi.text.x_text_portion_append import XTextPortionAppend as XTextPortionAppend
from .._pyi.text.x_text_range import XTextRange as XTextRange
from .._pyi.text.x_text_range_compare import XTextRangeCompare as XTextRangeCompare
from .._pyi.text.x_text_range_mover import XTextRangeMover as XTextRangeMover
from .._pyi.text.x_text_section import XTextSection as XTextSection
from .._pyi.text.x_text_sections_supplier import XTextSectionsSupplier as XTextSectionsSupplier
from .._pyi.text.x_text_shapes_supplier import XTextShapesSupplier as XTextShapesSupplier
from .._pyi.text.x_text_table import XTextTable as XTextTable
from .._pyi.text.x_text_table_cursor import XTextTableCursor as XTextTableCursor
from .._pyi.text.x_text_tables_supplier import XTextTablesSupplier as XTextTablesSupplier
from .._pyi.text.x_text_view_cursor import XTextViewCursor as XTextViewCursor
from .._pyi.text.x_text_view_cursor_supplier import XTextViewCursorSupplier as XTextViewCursorSupplier
from .._pyi.text.x_text_view_text_range_supplier import XTextViewTextRangeSupplier as XTextViewTextRangeSupplier
from .._pyi.text.x_word_cursor import XWordCursor as XWordCursor



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing


class DocumentHeaderField(object):
    """
    Struct Class

    This struct contains a name-value pair of a document header (i.e.
    
    the \"subject\" field and the appropriate value of a MIME message).

    See Also:
        `API DocumentHeaderField <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1DocumentHeaderField.html>`_
    """
    typeName: Literal['com.sun.star.ucb.DocumentHeaderField']

    def __init__(self, Name: typing.Optional[str] = ..., Value: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            Name (str, optional): Name value.
            Value (str, optional): Value value.
        """


    @property
    def Name(self) -> str:
        """
        The name of the header field.
        """


    @property
    def Value(self) -> str:
        """
        The value of the header field.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.configuration.backend
from typing_extensions import Literal
import typing
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .property_info import PropertyInfo as PropertyInfo_b5d21267
    from .x_layer_handler import XLayerHandler as XLayerHandler_c5d61289

class XLayerContentDescriber(XInterface_8f010a43):
    """
    describe the contents of a layer to an XLayerHandler object.
    
    The contents of the layer is contained in the sequence of PropertyInfo structures

    See Also:
        `API XLayerContentDescriber <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1XLayerContentDescriber.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.configuration.backend.XLayerContentDescriber']

    def describeLayer(self, aHandler: 'XLayerHandler_c5d61289', aPropertyInfos: 'typing.Tuple[PropertyInfo_b5d21267, ...]') -> None:
        """
        describes the contents of the layer to an XLayerHandler.

        Raises:
            com.sun.star.lang.NullPointerException: ``NullPointerException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
            MalformedDataException: ``MalformedDataException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.io
from .x_active_data_sink import XActiveDataSink as XActiveDataSink_b8d00ba3
from .x_connectable import XConnectable as XConnectable_980a0a96
from .x_markable_stream import XMarkableStream as XMarkableStream_b9bc0bc3
from .x_object_input_stream import XObjectInputStream as XObjectInputStream_dfb60d0b

class ObjectInputStream(XActiveDataSink_b8d00ba3, XConnectable_980a0a96, XMarkableStream_b9bc0bc3, XObjectInputStream_dfb60d0b):
    """
    Service Class

    is a stream which allows reading the data of persistent objects.
    
    Implementations of this service must fulfill the specifications of the DataInputStream service. It must be chained to an XMarkableStream. Therefore, it provides the XMarkableStream interface, and delegates the calls to the chained object.
    
    The written objects are held until this instance is destroyed. The references to the objects are read as four-byte integers. Data format reads:

    See Also:
        `API ObjectInputStream <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1io_1_1ObjectInputStream.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.2
from typing_extensions import Literal
from ..lang.event_object import EventObject as EventObject_a3d70b03
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing
from .x_content import XContent as XContent_79db0975
from .x_content_identifier import XContentIdentifier as XContentIdentifier_edc90d78


class ContentEvent(EventObject_a3d70b03):
    """
    Struct Class

    A structure for content events.

    See Also:
        `API ContentEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1ContentEvent.html>`_
    """
    typeName: Literal['com.sun.star.ucb.ContentEvent']

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = ..., Action: typing.Optional[int] = ..., Content: typing.Optional[XContent_79db0975] = ..., Id: typing.Optional[XContentIdentifier_edc90d78] = ...) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            Action (int, optional): Action value.
            Content (XContent, optional): Content value.
            Id (XContentIdentifier, optional): Id value.
        """


    @property
    def Action(self) -> int:
        """
        The action.
        
        The value can be one of the ContentAction constants.
        """


    @property
    def Content(self) -> XContent_79db0975:
        """
        The content to that the action is related (e.g., the content that was just physically destroyed, the content that was just inserted into a folder content).
        
        This member must be filled as follows:
        """


    @property
    def Id(self) -> XContentIdentifier_edc90d78:
        """
        A content identifier, which must be filled according to the action notified (e.g., the id of the folder content into which another content was inserted).
        
        This member must be filled as follows:
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.uri
from typing_extensions import Literal
from abc import ABC

class XExternalUriReferenceTranslator(ABC):
    """
    translates between external and internal URI references.
    
    Some URI schemes leave unspecified important aspects of how to interpret URIs of those schemes. For example, it is unspecified for “file” URLs how to map the byte sequences that constitute the path segments of a “file” URL to filenames on a given platform: The UNO environment always assumes that path segments of “file” URLs represent UTF-8–encoded strings (which have to be mapped to filenames in a platform-specific way), while other applications typically assume that path segments of “file” URLs directly represent a platform's byte-sequence filenames. This interface offers methods to translate between such internal URIs (e.g., UTF-8–encoded “file” URLs used within the UNO environment) and external URIs (e.g., byte-sequence–oriented “file” URLs used by other applications). Typically, only “file” URLs are affected by this translation.
    
    Since the translation process is based on URI schemes, relative URI references (that do not include a scheme) are left unmodified by the translation process.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XExternalUriReferenceTranslator <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1uri_1_1XExternalUriReferenceTranslator.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.uri.XExternalUriReferenceTranslator']

    def translateToExternal(self, internalUriReference: str) -> str:
        """
        returns the external counterpart of an internal URI reference.
        """
    def translateToInternal(self, externalUriReference: str) -> str:
        """
        returns the internal counterpart of an external URI reference.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt
from typing_extensions import Literal
import typing
from ..lang.x_component import XComponent as XComponent_98dc0ab5
if typing.TYPE_CHECKING:
    from .x_control_model import XControlModel as XControlModel_affc0b7e
    from .x_toolkit import XToolkit as XToolkit_7adf0992
    from .x_view import XView as XView_5f670847
    from .x_window_peer import XWindowPeer as XWindowPeer_99760ab0
    from ..uno.x_interface import XInterface as XInterface_8f010a43

class XControl(XComponent_98dc0ab5):
    """
    identifies a control.
    
    Implementations of this interface are abstract windows. The main reason to instantiate this implementation is to show the window on the screen. Before the window appears on the screen, the XControl.createPeer() method must be called.
    
    If the implementation of the control does not distinguish between model, view and controller, it must allow to set a new XGraphics in the view, so that the control can be printed.

    See Also:
        `API XControl <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XControl.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.XControl']

    def createPeer(self, Toolkit: 'XToolkit_7adf0992', Parent: 'XWindowPeer_99760ab0') -> None:
        """
        creates a \"child\" window on the screen.
        
        If the parent is NULL, then the desktop window of the toolkit is the parent.
        """
    def getContext(self) -> 'XInterface_8f010a43':
        """
        gets the context of the control.
        """
    def getModel(self) -> 'XControlModel_affc0b7e':
        """
        returns the model for this control.
        """
    def getPeer(self) -> 'XWindowPeer_99760ab0':
        """
        returns the peer which was previously created or set.
        """
    def getView(self) -> 'XView_5f670847':
        """
        returns the view of this control.
        """
    def isDesignMode(self) -> bool:
        """
        returns TRUE if the control is in design mode, FALSE otherwise.
        """
    def isTransparent(self) -> bool:
        """
        returns TRUE if the control is transparent, FALSE otherwise.
        """
    def setContext(self, Context: 'XInterface_8f010a43') -> None:
        """
        sets the context of the control.
        """
    def setDesignMode(self, bOn: bool) -> None:
        """
        sets the design mode for use in a design editor.
        
        Normally the control will be painted directly without a peer.
        """
    def setModel(self, Model: 'XControlModel_affc0b7e') -> bool:
        """
        sets a model for the control.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt
from typing_extensions import Literal
"""
Const

These constants are used to specify a result of executing a XMessageBox.

**since**

    LibreOffice 4.2

See Also:
    `API MessageBoxResults <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1MessageBoxResults.html>`_
"""
CANCEL: Literal[0]
"""
The user canceled the XMessageBox, by pressing \"Cancel\" or \"Abort\" button.
"""
OK: Literal[1]
"""
The user pressed the \"Ok\" button.
"""
YES: Literal[2]
"""
The user pressed the \"Yes\" button.
"""
NO: Literal[3]
"""
The user pressed the \"No\" button.
"""
RETRY: Literal[4]
"""
The user pressed the \"Retry\" button.
"""
IGNORE: Literal[5]
"""
The user pressed the \"Ignore\" button.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.inspection
from typing_extensions import Literal


class PropertyControlType(object):
    """
    Const

    describes pre-defined possible control types to be used to display and enter property values within an ObjectInspector.
    
    The type of a control determines its visual appearance, its behavior, and - important for property handlers using a control - the expected type when reading and writing the control's value.
    
    **since**
    
        OOo 2.0.3

    See Also:
        `API PropertyControlType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1inspection_1_1PropertyControlType.html>`_
    """
    ListBox: Literal[1]
    """
    denotes a control which allows the user to choose from a list of possible property values
    
    Controls of type ListBox exchange their values as string.
    
    Additionally, those controls support the XStringListControl interface.
    """
    ComboBox: Literal[2]
    """
    denotes a control which allows the user to choose from a list of possible property values, combined with the possibility to enter a new property value.
    
    Controls of type ComboBox exchange their values as string.
    
    Additionally, those controls support the XStringListControl interface.
    """
    TextField: Literal[3]
    """
    denotes a control which allows the user to enter property values consisting of a single line of text
    
    Controls of type TextField exchange their values as string.
    """
    MultiLineTextField: Literal[4]
    """
    denotes a control which allows the user to enter pure text, including line breaks
    
    Controls of type MultiLineTextField exchange their values as string.
    """
    CharacterField: Literal[5]
    """
    denotes a control which allows the user to enter a single character
    
    Controls of type CharacterField exchange their values as short, being a single UTF-16 character.
    """
    StringListField: Literal[6]
    """
    denotes a control which allows the user to enter a list of single-line strings
    
    Controls of type StringListField exchange their values as sequence< string >.
    """
    ColorListBox: Literal[7]
    """
    denotes a control which allows the user to choose from a list of colors.
    
    Controls of type ColorListBox usually exchange their values as com.sun.star.util.Color.
    
    Additionally, those controls support the XStringListControl interface. If you use this interface to add additional entries to the list box, which have no color associated with it, then you can also exchange values as string. That is, if you write a string into XPropertyControl.Value, and if this string has previously been added to the list using the XStringListControl interface, this string is selected. Vice versa, if the user selects one of those non-color strings in the list, then reading XPropertyControl.Value will retrieve you this string.
    """
    NumericField: Literal[8]
    """
    denotes a control which allows the user to enter a numerical value
    
    Controls of type NumericField exchange their values as double.
    
    Additionally, those controls support the XNumericControl interface.
    """
    DateField: Literal[9]
    """
    denotes a control which allows the user to enter a date value
    
    Controls of type DateField exchange their values as com.sun.star.util.Date.
    """
    TimeField: Literal[10]
    """
    denotes a control which allows the user to enter a time value
    
    Controls of type TimeField exchange their values as com.sun.star.util.Time.
    """
    DateTimeField: Literal[11]
    """
    denotes a control which allows the user to enter a combined date/time value
    
    Controls of type DateTimeField exchange their values as com.sun.star.util.DateTime.
    """
    HyperlinkField: Literal[12]
    """
    denotes a control which displays a string in a hyperlink-like appearance
    
    Controls of type HyperlinkField exchange their values as string.
    
    Additionally, those controls support the XHyperlinkControl interface.
    """
    Unknown: Literal[13]
    """
    denotes a non-standard property control, which is usually provided by an XPropertyHandler
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdb
from ..form.form_controller import FormController as FormController_c9180c74
from ..frame.x_controller import XController as XController_b00e0b8f
from ..frame.x_dispatch_provider import XDispatchProvider as XDispatchProvider_fc690de6
from ..lang.x_initialization import XInitialization as XInitialization_d46c0cca
from ..ui.x_context_menu_interception import XContextMenuInterception as XContextMenuInterception_38f90fac

class DataSourceBrowser(FormController_c9180c74, XController_b00e0b8f, XDispatchProvider_fc690de6, XInitialization_d46c0cca, XContextMenuInterception_38f90fac):
    """
    Service Class

    implements a component which allows browsing the data sources registered on the system.
    
    This service implements a user interface for browsing data sources registered on the com.sun.star.sdb.DatabaseContext instance of the system.
    
    It is possible to navigate through all the data sources, it's queries and it's tables. The queries/tables can be displayed in a grid-like view, where functionality for searching, sorting, filtering, and such is provided.
    
    Usually, you won't instantiate this service directly, instead you use the dispatch mechanisms of the application framework to load the URL .component:DB/DataSourceBrowser into an arbitrary frame. This should involve a com.sun.star.sdb.ContentLoader service, which creates and initializes the browser.
    
    Some aspects of the browser can be controlled from outside, e.g., it is possible to dispatch a sort or filter request, if a table or query is being displayed.
    
    The communication between the browser and external instances works in two ways.
    The way in is provided by the com.sun.star.frame.XDispatchProvider interface the service exports (Please see below for more details on this).
    The way out works in another way. There are several URLs which an external instance can provide dispatches for (usually by implementing a com.sun.star.frame.XDispatchProviderInterceptor for the parent frame of the browser), thus indicating that the browser should provide special functionality.
    In this case, the browser displays and maintains some additional slots (to be more concrete: toolbox items), which, upon triggering, call the com.sun.star.frame.XDispatch.dispatch() method of the object provided by the external instance.
    
    In particular, the supported URLs for communicating to an external instance are:
    
    For all kinds of URLs, the parameters supplied during dispatching build up a DataAccessDescriptor, where the following properties are present:
    
    The default for DataAccessDescriptor.Selection is to contain bookmarks, if not specified otherwise by DataAccessDescriptor.BookmarkSelection.
    
    **since**
    
        OOo 3.0

    See Also:
        `API DataSourceBrowser <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1DataSourceBrowser.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.ucb
from typing_extensions import Literal
"""
Const

These are the possible values for Rule.Action.

See Also:
    `API RuleAction <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ucb_1_1RuleAction.html>`_
"""
NONE: Literal[0]
"""
\"None\" - Do nothing.
"""
SHOW: Literal[1]
"""
\"Show\" - Shows object when term matches.
"""
HIDE: Literal[2]
"""
\"Hide\" - Hides object when term matches.
"""
MARK: Literal[3]
"""
\"Mark\" - Marks object when term matches.
"""
UNMARK: Literal[4]
"""
\"UnMark\" - Removes mark from object when term matches.
"""
MARKREAD: Literal[5]
"""
\"MarkRead\" - Marks object as read when term matches.
"""
MARKUNREAD: Literal[6]
"""
\"MarkUnRead\" - Marks object as not read when term matches.
"""
MOVE: Literal[7]
"""
\"Move\" - Moves object to Rule.Parameter when term matches.
"""
COPY: Literal[8]
"""
\"Copy\" - Copies object to Rule.Parameter when term matches.
"""
DELETE: Literal[9]
"""
\"Delete\" - Deletes object when term matches.
"""
LINK: Literal[10]
"""
\"Link\" - Creates a link to Rule.Parameter when term matches.
"""
FORWARD: Literal[11]
"""
\"Forward\" - Forwards object to Rule.Parameter when term matches.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.lang
from typing_extensions import Literal


class SystemDependent(object):
    """
    Const

    These constants are used to specify systems which depend on return values.
    
    You should avoid system-dependent methods if possible.
    
    The Symbols are now prepended with SYSTEM_ thus we avoid collisions with system headers.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API SystemDependent <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1lang_1_1SystemDependent.html>`_
    """
    SYSTEM_WIN32: Literal[1]
    """
    The called interface method returns a value specified for Windows.
    
    These are Windows XP or higher.
    """
    SYSTEM_WIN16: Literal[2]
    """
    The called interface method returns a value specified for 16-bit Windows.
    
    This is Windows 3.11.
    """
    SYSTEM_JAVA: Literal[3]
    """
    The called interface method returns a value specified for Java.
    
    These are JRE 1.1, JRE 1.2, JDK 1.1, JDK 1.2 or higher.
    
    The return should be a handle to a Java object locked with the call JavaEnvironment->NewGlobalRef( ... ) by the callee.
    """
    SYSTEM_OS2: Literal[4]
    """
    The called interface method returns a value specified for OS/2.
    """
    SYSTEM_MAC: Literal[5]
    """
    The called interface method returns a value specified for macOS.
    """
    SYSTEM_XWINDOW: Literal[6]
    """
    The called interface method returns a value specified for the X Window System.
    """
    SYSTEM_IOS: Literal[7]
    """
    The called interface method returns a value specified for iOS.
    """
    SYSTEM_ANDROID: Literal[8]
    """
    The called interface method returns a value specified for Android.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.embed
from typing_extensions import Literal
"""
Const

The constant set contains flags describing miscellaneous characteristics of embedded objects.

The constant values can be combined with \"or\" operation. The first 32 bits are reserved for MS values, they are added because this API is going to be used to embed MS OLE objects into OOo documents, so there should be a possibility to transfer all the possible MS flags to container. In case own specific values should be added those bits can not be used.

See Also:
    `API EmbedMisc <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1embed_1_1EmbedMisc.html>`_
"""
MS_EMBED_RECOMPOSEONRESIZE: Literal[1]
"""
means that the object wish to regenerate view representation if it's view in the container is resized.
"""
MS_EMBED_ONLYICONIC: Literal[2]
"""
The object has no view representation except icon.
"""
MS_EMBED_INSERTNOTREPLACE: Literal[4]
"""
If the object is generated from a selection, the selection should not be removed, the object should be inserted beside the selection.
"""
MS_EMBED_STATIC: Literal[8]
"""
The object is a static object that contains only representation.
"""
MS_EMBED_CANTLINKINSIDE: Literal[16]
MS_EMBED_CANLINKBYOLE1: Literal[32]
MS_EMBED_ISLINKOBJECT: Literal[64]
MS_EMBED_INSIDEOUT: Literal[128]
MS_EMBED_ACTIVATEWHENVISIBLE: Literal[256]
MS_EMBED_RENDERINGISDEVICEINDEPENDENT: Literal[512]
MS_EMBED_INVISIBLEATRUNTIME: Literal[1024]
MS_EMBED_ALWAYSRUN: Literal[2048]
MS_EMBED_ACTSLIKEBUTTON: Literal[4096]
MS_EMBED_ACTSLIKELABEL: Literal[8192]
MS_EMBED_NOUIACTIVATE: Literal[16384]
MS_EMBED_ALIGNABLE: Literal[32768]
MS_EMBED_SIMPLEFRAME: Literal[65536]
MS_EMBED_SETCLIENTSITEFIRST: Literal[131072]
MS_EMBED_IMEMODE: Literal[262144]
MS_EMBED_IGNOREACTIVATEWHENVISIBLE: Literal[524288]
MS_EMBED_WANTSTOMENUMERGE: Literal[1048576]
MS_EMBED_SUPPORTSMULTILEVELUNDO: Literal[2097152]
EMBED_ACTIVATEIMMEDIATELY: Literal[4294967296]
EMBED_NEVERRESIZE: Literal[8589934592]
EMBED_NEEDSSIZEONLOAD: Literal[17179869184]
"""
The object needs the size to be provided from the container after it is loaded to function in optimal way.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.awt
# Libre Office Version: 7.2
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum



See Also:
    `API GradientStyle <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt.html#aa6b9d577a1700f29923f49f7b77d165f>`_
"""

AXIAL: 'uno.Enum'
"""
specifies an axial gradient.
"""
ELLIPTICAL: 'uno.Enum'
"""
specifies an elliptical gradient.
"""
LINEAR: 'uno.Enum'
"""
specifies a linear gradient.
"""
RADIAL: 'uno.Enum'
"""
specifies a radial gradient.
"""
RECT: 'uno.Enum'
"""
specifies a gradient in the shape of a rectangle.
"""
SQUARE: 'uno.Enum'
"""
specifies a gradient in the shape of a square.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
"""
Const

specifies region type of DataPilot table range

This constant set is used to indicate the type of output range desired when XDataPilotTable2.getOutputRangeByType() is called, which returns a different cell range depending upon the value passed to it as the argument.

**since**

    OOo 3.0

See Also:
    `API DataPilotOutputRangeType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotOutputRangeType.html>`_
"""
WHOLE: Literal[0]
"""
whole DataPilot output range including the header area above the table where the filter and page field buttons are located.
"""
TABLE: Literal[1]
"""
whole table but without the header area where the filter and page field buttons are located.
"""
RESULT: Literal[2]
"""
result area where the result values are displayed.

This also includes the column and row subtotal areas when they are displayed.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.deployment
from typing_extensions import Literal
import typing
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from ..util.x_modify_broadcaster import XModifyBroadcaster as XModifyBroadcaster_fd990df0
if typing.TYPE_CHECKING:
    from ..beans.named_value import NamedValue as NamedValue_a37a0af3
    from .x_package import XPackage as XPackage_cb1f0c4d
    from .x_package_type_info import XPackageTypeInfo as XPackageTypeInfo_3bc70f7b
    from ..task.x_abort_channel import XAbortChannel as XAbortChannel_baca0bc4
    from ..ucb.x_command_environment import XCommandEnvironment as XCommandEnvironment_fb330dee

class XPackageManager(XComponent_98dc0ab5, XModifyBroadcaster_fd990df0):
    """
    The XPackageManager interface is used to add or remove packages to a specific repository.
    
    This interface represents a particular repository. Packages are deployable files, e.g. scripts or UNO components.
    
    Adding a UNO package means that a copy of the package is stored in the repository.
    
    Removing a UNO package means that the previously added package is removed from the repository.
    
    All interface methods do neither register nor revoke an extension. This happens exclusively by XExtensionManager.
    
    Objects of this interface are created using the XPackageManagerFactory service resp. the singleton  /singletons/com.sun.star.deployment.thePackageManagerFactory .
    
    **since**
    
        OOo 2.0
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XPackageManager <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1deployment_1_1XPackageManager.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.deployment.XPackageManager']

    def addPackage(self, url: str, properties: 'typing.Tuple[NamedValue_a37a0af3, ...]', mediaType: str, xAbortChannel: 'XAbortChannel_baca0bc4', xCmdEnv: 'XCommandEnvironment_fb330dee') -> 'XPackage_cb1f0c4d':
        """
        adds a UNO package.
        
        The properties argument is currently only used to suppress the license information for shared extensions.

        Raises:
            DeploymentException: ``DeploymentException``
            com.sun.star.ucb.CommandFailedException: ``CommandFailedException``
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def checkPrerequisites(self, extension: 'XPackage_cb1f0c4d', xAbortChannel: 'XAbortChannel_baca0bc4', xCmdEnv: 'XCommandEnvironment_fb330dee') -> int:
        """
        checks if the extension can be used.
        
        The extension must be managed by this package manager, that is, it must be recorded in its database. The package manager calls XPackage.checkPrerequisites and updates its data base with the result. The result, which is from Prerequisites will be returned.

        Raises:
            DeploymentException: ``DeploymentException``
            com.sun.star.ucb.CommandFailedException: ``CommandFailedException``
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def createAbortChannel(self) -> 'XAbortChannel_baca0bc4':
        """
        creates a command channel to be used to asynchronously abort a command.
        """
    def getContext(self) -> str:
        """
        returns the underlying deployment context, that is, the name of the repository.
        """
    def getDeployedPackage(self, identifier: str, fileName: str, xCmdEnv: 'XCommandEnvironment_fb330dee') -> 'XPackage_cb1f0c4d':
        """
        gets a deployed package.

        Raises:
            DeploymentException: ``DeploymentException``
            com.sun.star.ucb.CommandFailedException: ``CommandFailedException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def getDeployedPackages(self, xAbortChannel: 'XAbortChannel_baca0bc4', xCmdEnv: 'XCommandEnvironment_fb330dee') -> 'typing.Tuple[XPackage_cb1f0c4d, ...]':
        """
        gets all currently deployed packages.

        Raises:
            DeploymentException: ``DeploymentException``
            com.sun.star.ucb.CommandFailedException: ``CommandFailedException``
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def getExtensionsWithUnacceptedLicenses(self, xCmdEnv: 'XCommandEnvironment_fb330dee') -> 'typing.Tuple[XPackage_cb1f0c4d, ...]':
        """
        returns all extensions which are currently not in use because the user did not accept the license.
        
        The function will not return any object for the user repository, because a user extension will not be kept in the user repository if its license is declined. Only extensions which are registered at start-up of OOo, that is, shared and bundled extensions, can be returned.
        
        Extensions which allow the license to be suppressed, that is, it does not need to be displayed, and which are installed with the corresponding option, are also not returned.

        Raises:
            DeploymentException: ``DeploymentException``
        """
    def getSupportedPackageTypes(self) -> 'typing.Tuple[XPackageTypeInfo_3bc70f7b, ...]':
        """
        gets the supported XPackageTypeInfos.
        """
    def importExtension(self, extension: 'XPackage_cb1f0c4d', xAbortChannel: 'XAbortChannel_baca0bc4', xCmdEnv: 'XCommandEnvironment_fb330dee') -> 'XPackage_cb1f0c4d':
        """
        adds an extension.
        
        This copies the extension. If it was from the same repository, which is represented by this XPackageManager interface, then nothing happens.

        Raises:
            DeploymentException: ``DeploymentException``
            com.sun.star.ucb.CommandFailedException: ``CommandFailedException``
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def isReadOnly(self) -> bool:
        """
        indicates that this implementation cannot be used for tasks which require write access to the location where the extensions are installed.
        
        Normally one would call a method and handle the exception if writing failed. However, a GUI interface may need to know beforehand if writing is allowed. For example, the Extension Manager dialog needs to enable / disable the Add button depending if the user has write permission. Only the XPackageManager implementation knows the location of the installed extensions. Therefore it is not possible to check \"externally\" for write permission.
        """
    def reinstallDeployedPackages(self, force: bool, xAbortChannel: 'XAbortChannel_baca0bc4', xCmdEnv: 'XCommandEnvironment_fb330dee') -> None:
        """
        Expert feature: erases the underlying registry cache and reinstalls all previously added packages.
        
        Please keep in mind that all registration status get lost.
        
        Please use this in case of suspected cache inconsistencies only.

        Raises:
            DeploymentException: ``DeploymentException``
            com.sun.star.ucb.CommandFailedException: ``CommandFailedException``
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def removePackage(self, identifier: str, fileName: str, xAbortChannel: 'XAbortChannel_baca0bc4', xCmdEnv: 'XCommandEnvironment_fb330dee') -> None:
        """
        removes a UNO package.

        Raises:
            DeploymentException: ``DeploymentException``
            com.sun.star.ucb.CommandFailedException: ``CommandFailedException``
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def synchronize(self, xAbortChannel: 'XAbortChannel_baca0bc4', xCmdEnv: 'XCommandEnvironment_fb330dee') -> bool:
        """
        synchronizes the extension database with the contents of the extensions folder.
        
        Added extensions will be added to the database and removed extensions will be removed from the database.

        Raises:
            DeploymentException: ``DeploymentException``
            com.sun.star.ucb.ContentCreationException: ``ContentCreationException``
            com.sun.star.ucb.CommandFailedException: ``CommandFailedException``
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.xml.dom
from typing_extensions import Literal
import typing
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .node_type import NodeType as NodeType_a3b00aef
    from .x_document import XDocument as XDocument_aebc0b5e
    from .x_named_node_map import XNamedNodeMap as XNamedNodeMap_de600ca8
    from .x_node_list import XNodeList as XNodeList_ae540b41

class XNode(XInterface_8f010a43):
    """
    The primary dom datatype.
    
    The Node interface is the primary datatype for the entire Document Object Model. It represents a single node in the document tree. While all objects implementing the Node interface expose methods for dealing with children, not all objects implementing the Node interface may have children. For example, Text nodes may not have children, and adding children to such nodes results in a DOMException being raised.
    
    The attributes nodeName, nodeValue and attributes are included as a mechanism to get at node information without casting down to the specific derived interface. In cases where there is no obvious mapping of these attributes for a specific nodeType (e.g., nodeValue for an Element or attributes for a Comment ), this returns null. Note that the specialized interfaces may contain additional and more convenient mechanisms to get and set the relevant information.
    
    The values of nodeName, nodeValue, and attributes vary according to the node type as follows:
    
    **since**
    
        OOo 2.0

    See Also:
        `API XNode <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1XNode.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.xml.dom.XNode']

    def appendChild(self, newChild: 'XNode') -> 'XNode':
        """
        Adds the node newChild to the end of the list of children of this node.
        
        HIERARCHY_REQUEST_ERR: Raised if this node is of a type that does not allow children of the type of the newChild node, or if the node to append is one of this node's ancestors or this node itself.
        
        WRONG_DOCUMENT_ERR: Raised if newChild was created from a different document than the one that created this node.
        
        NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly or if the previous parent of the node being inserted is readonly.

        Raises:
            DOMException: ``DOMException``
        """
    def cloneNode(self, deep: bool) -> 'XNode':
        """
        Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes.
        """
    def getAttributes(self) -> 'XNamedNodeMap_de600ca8':
        """
        A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.
        """
    def getChildNodes(self) -> 'XNodeList_ae540b41':
        """
        A NodeList that contains all children of this node.
        """
    def getFirstChild(self) -> 'XNode':
        """
        The first child of this node.
        """
    def getLastChild(self) -> 'XNode':
        """
        The last child of this node.
        """
    def getLocalName(self) -> str:
        """
        Returns the local part of the qualified name of this node.
        """
    def getNamespaceURI(self) -> str:
        """
        The namespace URI of this node, or null if it is unspecified.
        """
    def getNextSibling(self) -> 'XNode':
        """
        The node immediately following this node.
        """
    def getNodeName(self) -> str:
        """
        The name of this node, depending on its type; see the table above.
        """
    def getNodeType(self) -> 'NodeType_a3b00aef':
        """
        A code representing the type of the underlying object, as defined above.
        """
    def getNodeValue(self) -> str:
        """
        The value of this node, depending on its type; see the table above.
        
        DOMSTRING_SIZE_ERR: Raised when it would return more characters than fit in a DOMString variable on the implementation platform.

        Raises:
            DOMException: ``DOMException``
        """
    def getOwnerDocument(self) -> 'XDocument_aebc0b5e':
        """
        The Document object associated with this node.
        """
    def getParentNode(self) -> 'XNode':
        """
        The parent of this node.
        """
    def getPrefix(self) -> str:
        """
        The namespace prefix of this node, or null if it is unspecified.
        """
    def getPreviousSibling(self) -> 'XNode':
        """
        The node immediately preceding this node.
        """
    def hasAttributes(self) -> bool:
        """
        Returns whether this node (if it is an element) has any attributes.
        """
    def hasChildNodes(self) -> bool:
        """
        Returns whether this node has any children.
        """
    def insertBefore(self, newChild: 'XNode', refChild: 'XNode') -> 'XNode':
        """
        Inserts the node newChild before the existing child node refChild.
        
        HIERARCHY_REQUEST_ERR: Raised if this node is of a type that does not allow children of the type of the newChild node, or if the node to insert is one of this node's ancestors or this node itself.
        
        WRONG_DOCUMENT_ERR: Raised if newChild was created from a different document than the one that created this node.
        
        NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly or if the parent of the node being inserted is readonly.
        
        NOT_FOUND_ERR: Raised if refChild is not a child of this node.

        Raises:
            DOMException: ``DOMException``
        """
    def isSupported(self, feature: str, ver: str) -> bool:
        """
        Tests whether the DOM implementation implements a specific feature and that feature is supported by this node.
        """
    def normalize(self) -> None:
        """
        Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a \"normal\" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes.
        """
    def removeChild(self, oldChild: 'XNode') -> 'XNode':
        """
        Removes the child node indicated by oldChild from the list of children, and returns it.
        
        NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly.
        
        NOT_FOUND_ERR: Raised if oldChild is not a child of this node.

        Raises:
            DOMException: ``DOMException``
        """
    def replaceChild(self, newChild: 'XNode', oldChild: 'XNode') -> 'XNode':
        """
        Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        
        HIERARCHY_REQUEST_ERR: Raised if this node is of a type that does not allow children of the type of the newChild node, or if the node to put in is one of this node's ancestors or this node itself.
        
        WRONG_DOCUMENT_ERR: Raised if newChild was created from a different document than the one that created this node.
        
        NO_MODIFICATION_ALLOWED_ERR: Raised if this node or the parent of the new node is readonly.
        
        NOT_FOUND_ERR: Raised if oldChild is not a child of this node.

        Raises:
            DOMException: ``DOMException``
        """
    def setNodeValue(self, nodeValue: str) -> None:
        """
        The value of this node, depending on its type; see the table above.
        
        NO_MODIFICATION_ALLOWED_ERR: Raised when the node is readonly.
        
        DOMSTRING_SIZE_ERR: Raised when it would return more characters than fit in a DOMString variable on the implementation platform.

        Raises:
            DOMException: ``DOMException``
        """
    def setPrefix(self, prefix: str) -> None:
        """
        The namespace prefix of this node, or null if it is unspecified.
        
        INVALID_CHARACTER_ERR: Raised if the specified prefix contains an illegal character, per the XML 1.0 specification .
        
        NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly.
        
        NAMESPACE_ERR: Raised if the specified prefix is malformed per the Namespaces in XML specification, if the namespaceURI of this node is null, if the specified prefix is \"xml\" and the namespaceURI of this node is different from \"http://www.w3.org/XML/1998/namespace\", if this node is an attribute and the specified prefix is \"xmlns\" and the namespaceURI of this node is different from \" http://www.w3.org/2000/xmlns/\", or if this node is an attribute and the qualifiedName of this node is \"xmlns\" .

        Raises:
            DOMException: ``DOMException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.document
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73

class XDocumentRecovery(ABC):
    """
    is the interface to be implemented by documents who wish to participate in the document emergency-save / recovery process.

    See Also:
        `API XDocumentRecovery <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1document_1_1XDocumentRecovery.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.document.XDocumentRecovery']

    def recoverFromFile(self, SourceLocation: str, SalvagedFile: str, MediaDescriptor: 'typing.Tuple[PropertyValue_c9610c73, ...]') -> None:
        """
        recovers the document after a previous emergency or session save.
        
        The document itself has previously been created, but not loaded (via com.sun.star.frame.XLoadable.load()) or initialized (via com.sun.star.frame.XLoadable.initNew()).
        
        Upon successful return, the document must be fully initialized. In particular, the caller is not responsible for calling com.sun.star.frame.XModel.attachResource(). Instead, the implementation is responsible to do so, if required.
        
        A default implementation of this method could simply delegate this call to com.sun.star.frame.XLoadable.load(), followed by com.sun.star.frame.XModel.attachResource().

        Raises:
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def storeToRecoveryFile(self, TargetLocation: str, MediaDescriptor: 'typing.Tuple[PropertyValue_c9610c73, ...]') -> None:
        """
        does an emergency save of the document
        
        A default implementation of this method could simply delegate this call to com.sun.star.frame.XStorable.storeToURL().

        Raises:
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def wasModifiedSinceLastSave(self) -> bool:
        """
        determines whether the document has been modified since the last call to storeToRecoveryFile().
        
        If storeToRecoveryFile has not been called before, this method returns whether the document has been modified since it has been loaded respectively created.
        
        When saving a session, either in case of an emergency (when OpenOffice.org crashed), or during a periodic session save as configured by the user, storeToRecoveryFile() is called for every document where wasModifiedSinceLastSave returns TRUE.
        
        It's allowed to implement this method sloppy, by returning TRUE in cases where it is not sure whether the document actually has been modified. So, the most simple implementation could simply delegate this call to com.sun.star.util.XModifiable.isModified(). (Well, actually that's the second simple implementation, the most simple one would, still legitimately, always return TRUE.)
        
        However, in such a case, the document might be saved more often than needed. In particular during the periodic session save, this might become a problem when saving is expensive, for a single document or the sum of all open documents.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.chart2
from .data_point_properties import DataPointProperties as DataPointProperties_24a00efd
from ..style.character_properties import CharacterProperties as CharacterProperties_1d4f0ef3
from ..style.character_properties_asian import CharacterPropertiesAsian as CharacterPropertiesAsian_6d8a10df
from ..style.character_properties_complex import CharacterPropertiesComplex as CharacterPropertiesComplex_90ca11cb

class DataPoint(DataPointProperties_24a00efd, CharacterProperties_1d4f0ef3, CharacterPropertiesAsian_6d8a10df, CharacterPropertiesComplex_90ca11cb):
    """
    Service Class


    See Also:
        `API DataPoint <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart2_1_1DataPoint.html>`_
    """
    @property
    def Offset(self) -> float:
        """
        this property handles the style.
        
        This property must support the service com.sun.star.style.Style.
        
        It should provide templates for all properties in this service, thus it must also support DataPoint.
        
        Gives the offset of the data point. For PieDiagrams this would be the percentage by which pies are dragged out of the cake.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.report
from typing_extensions import Literal
import typing
from .x_report_control_model import XReportControlModel as XReportControlModel_2d800f4a
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..drawing.homogen_matrix3 import HomogenMatrix3 as HomogenMatrix3_f0fb0d69

class XShape(XReportControlModel_2d800f4a):
    """

    See Also:
        `API XShape <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1report_1_1XShape.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.report.XShape']

    @property
    def CustomShapeGeometry(self) -> 'typing.Tuple[PropertyValue_c9610c73, ...]':
        """
        This property describes the geometry of the CustomShape.
        
        The CustomShapeEngine that is used should be able to get on with the content of this property.
        
        If the CustomShapeEngine property is \"com.sun.star.drawing.EnhancedCustomShapeEngine\", then this property is containing properties as they are specified in the service com.sun.star.drawing.EnhancedCustomShapeGeometry
        """

    @property
    def CustomShapeData(self) -> str:
        """
        This property can be used to store data that the CustomShapeEngine may use for rendering.
        """

    @property
    def CustomShapeEngine(self) -> str:
        """
        This property contains the CustomShapeEngine service name that has to be used for rendering.
        """

    @property
    def Opaque(self) -> bool:
        """
        determines if the object is opaque or transparent for text.
        """

    @property
    def Transformation(self) -> 'HomogenMatrix3_f0fb0d69':
        """
        this property lets you get and set the transformation matrix for this shape.
        
        The transformation is a 3x3 homogeneous matrix and can contain translation, rotation, shearing and scaling.
        """

    @property
    def ZOrder(self) -> int:
        """
        is used to query or change the ZOrder of this Shape.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.office
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from .x_annotation import XAnnotation as XAnnotation_bb8f0be7
    from .x_annotation_enumeration import XAnnotationEnumeration as XAnnotationEnumeration_58fe106e

class XAnnotationAccess(ABC):
    """
    This interface gives access to the annotation for a document content.

    See Also:
        `API XAnnotationAccess <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1office_1_1XAnnotationAccess.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.office.XAnnotationAccess']

    def createAndInsertAnnotation(self) -> 'XAnnotation_bb8f0be7':
        """
        creates a new annotation and inserts it into the document content.
        """
    def createAnnotationEnumeration(self) -> 'XAnnotationEnumeration_58fe106e':
        """
        """
    def removeAnnotation(self, annotation: 'XAnnotation_bb8f0be7') -> None:
        """
        removes the annotation from this document content.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sheet
from typing_extensions import Literal


class StatusBarFunction(object):
    """
    Const

    used to specify the function used to calculate a result in the spreadsheet's status bar.

    See Also:
        `API StatusBarFunction <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet_1_1StatusBarFunction.html>`_
    """
    NONE: Literal[0]
    """
    nothing is calculated.
    """
    AVERAGE: Literal[1]
    """
    average of all numerical values is calculated.
    """
    COUNTNUMS: Literal[2]
    """
    all values, including non-numerical values, are counted.
    """
    COUNT: Literal[3]
    """
    numerical values are counted.
    """
    MAX: Literal[4]
    """
    maximum value of all numerical values is calculated.
    """
    MIN: Literal[5]
    """
    minimum value of all numerical values is calculated.
    """
    SUM: Literal[9]
    """
    sum of all numerical values is calculated.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from .formula_op_code_map_entry import FormulaOpCodeMapEntry as FormulaOpCodeMapEntry_37da0f61
    from .formula_token import FormulaToken as FormulaToken_bd1c0bf8

class XFormulaOpCodeMapper(ABC):
    """
    gives access to spreadsheet compiler token interns.

    See Also:
        `API XFormulaOpCodeMapper <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XFormulaOpCodeMapper.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sheet.XFormulaOpCodeMapper']

    def getAvailableMappings(self, Language: int, Groups: int) -> 'typing.Tuple[FormulaOpCodeMapEntry_37da0f61, ...]':
        """
        returns a sequence of map entries for all available elements of a given formula language.
        
        Each element of the formula language in parameter Language is mapped to a FormulaToken containing the internal OpCode used by the spreadsheet application in FormulaToken.OpCode and by contract maybe additional information in FormulaToken.Data. See getMappings() for more details.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def getMappings(self, Names: 'typing.Tuple[str, ...]', Language: int) -> 'typing.Tuple[FormulaToken_bd1c0bf8, ...]':
        """
        returns a sequence of tokens matching the input sequence of strings in order.
        
        Each string element in parameter Names according to the formula language in parameter Language is mapped to a FormulaToken containing the internal OpCode used by the spreadsheet application in FormulaToken.OpCode and by contract maybe additional information in FormulaToken.Data.
        
        The order of the FormulaToken sequence returned matches the input order of the string sequence.
        
        An unknown Name string gets the OpCode value of OpCodeUnknown assigned.
        
        Additional information in FormulaToken.Data is returned for:

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    @property
    def OpCodeExternal(self) -> int:
        """
        OpCode value used for external Add-In functions.
        
        Needed to be able to identify which of the function names map to an Add-In implementation where this OpCode is used in the returned mapping and the programmatic name is available as additional information.
        """

    @property
    def OpCodeUnknown(self) -> int:
        """
        OpCode value used for unknown functions.
        
        Used to identify which of the function names queried with getMappings() are unknown to the implementation.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.chart2
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from ..awt.size import Size as Size_576707ef
from .symbol_style import SymbolStyle as SymbolStyle_baa20bd3
from ..drawing.poly_polygon_bezier_coords import PolyPolygonBezierCoords as PolyPolygonBezierCoords_7ec5114b
from ..graphic.x_graphic import XGraphic as XGraphic_a4da0afc


class Symbol(object):
    """
    Struct Class

    properties that are used for DataSeries that display symbols.

    See Also:
        `API Symbol <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1chart2_1_1Symbol.html>`_
    """
    typeName: Literal['com.sun.star.chart2.Symbol']

    def __init__(self, Style: typing.Optional[SymbolStyle_baa20bd3] = ..., PolygonCoords: typing.Optional[PolyPolygonBezierCoords_7ec5114b] = ..., StandardSymbol: typing.Optional[int] = ..., Graphic: typing.Optional[XGraphic_a4da0afc] = ..., Size: typing.Optional[Size_576707ef] = ..., BorderColor: typing.Optional[int] = ..., FillColor: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            Style (SymbolStyle, optional): Style value.
            PolygonCoords (PolyPolygonBezierCoords, optional): PolygonCoords value.
            StandardSymbol (int, optional): StandardSymbol value.
            Graphic (XGraphic, optional): Graphic value.
            Size (Size, optional): Size value.
            BorderColor (int, optional): BorderColor value.
            FillColor (int, optional): FillColor value.
        """


    @property
    def Style(self) -> SymbolStyle_baa20bd3:
        """
        determines which of the following members determines the appearance of the symbol.
        """


    @property
    def PolygonCoords(self) -> PolyPolygonBezierCoords_7ec5114b:
        """
        The given polygon is used as symbol.
        """


    @property
    def StandardSymbol(self) -> int:
        """
        Use the nth standard symbol, if Style is set to SymbolStyle.STANDARD.
        
        If n is the number of standard symbols available in an implementation, the symbol number is StandardSymbol modulo n.
        
        The default implementation for example currently uses 8 different standard symbols that are matched to the numbers 0 to 7.
        """


    @property
    def Graphic(self) -> XGraphic_a4da0afc:
        """
        use this graphic as symbol
        """


    @property
    def Size(self) -> Size_576707ef:
        """
        The size of the symbol in 100th of a mm.
        """


    @property
    def BorderColor(self) -> int:
        """
        The color used for drawing the border of symbols.
        
        Only effective if Style is SymbolStyle.AUTO, SymbolStyle.STANDARD or SymbolStyle.POLYGON.
        """


    @property
    def FillColor(self) -> int:
        """
        The color used for filling symbols that contain closed polygons.
        
        Only effective if Style is SymbolStyle.AUTO, SymbolStyle.STANDARD or SymbolStyle.POLYGON.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.drawing
from typing_extensions import Literal
"""
Const

defines how an EnhancedCustomShapeParameter has to be interpreted

See Also:
    `API EnhancedCustomShapeParameterType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeParameterType.html>`_
"""
NORMAL: Literal[0]
"""
the value of the point component is normal, the Coordinate is taken as it is
"""
EQUATION: Literal[1]
"""
the value of the point component has to be interpreted as index to an Equation
"""
ADJUSTMENT: Literal[2]
"""
the value of the point component has to be interpreted as index into the list of AdjustmentValues
"""
LEFT: Literal[3]
"""
the logical left border of the CustomShape is used
"""
TOP: Literal[4]
"""
the logical top border of the CustomShape is used
"""
RIGHT: Literal[5]
"""
the logical right border of the CustomShape is used
"""
BOTTOM: Literal[6]
"""
the logical bottom border of the CustomShape is used
"""
XSTRETCH: Literal[7]
"""
the x value of the stretch point is used
"""
YSTRETCH: Literal[8]
"""
the y value of the stretch point is used
"""
HASSTROKE: Literal[9]
"""
If the shape has a line style, a value of 1 is used.
"""
HASFILL: Literal[10]
"""
If the shape has a fill style, a value of 1 is used.
"""
WIDTH: Literal[11]
"""
The width of the svg:viewBox is used.
"""
HEIGHT: Literal[12]
"""
The height of the svg:viewBox is used.
"""
LOGWIDTH: Literal[13]
"""
The logical width of the shape is used.
"""
LOGHEIGHT: Literal[14]
"""
The logical height of the shape is used.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.ucb
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_content import XContent as XContent_79db0975
    from .x_content_identifier import XContentIdentifier as XContentIdentifier_edc90d78

class XContentIdentifierMapping(XInterface_8f010a43):
    """
    A mapping from a (source) set of XContentIdentifiers to another (target) set of XContentIdentifiers.
    
    For convenience and performance, mapping between the string representations of source/target XContentIdentifiers, as well as mapping between XContents identified by source/target XContentIdentifiers is also supported.
    
    This interface can be useful in cases where the identifiers (and associated contents) returned by the various methods of an XContentAccess need to be mapped to some other space of identifiers (and associated contents).

    See Also:
        `API XContentIdentifierMapping <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ucb_1_1XContentIdentifierMapping.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ucb.XContentIdentifierMapping']

    def mapContent(self, Source: 'XContent_79db0975') -> 'XContent_79db0975':
        """
        Map the XContent identified by an XContentIdentifier.
        """
    def mapContentIdentifier(self, Source: 'XContentIdentifier_edc90d78') -> 'XContentIdentifier_edc90d78':
        """
        Map an XContentIdentifier.
        """
    def mapContentIdentifierString(self, Source: str) -> str:
        """
        Map the string representation of an XContentIdentifier.
        """
    def mapRow(self, Value: object) -> bool:
        """
        Map the content identifiers (or related data) contained in the columns of a com.sun.star.sdbc.XRow.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdb
from .x_parameters_supplier import XParametersSupplier as XParametersSupplier_fc7c0e01
from .x_single_select_query_analyzer import XSingleSelectQueryAnalyzer as XSingleSelectQueryAnalyzer_66ad10b7
from ..sdbcx.x_columns_supplier import XColumnsSupplier as XColumnsSupplier_f0600da9
from ..sdbcx.x_tables_supplier import XTablesSupplier as XTablesSupplier_e1ad0d23

class SingleSelectQueryAnalyzer(XParametersSupplier_fc7c0e01, XSingleSelectQueryAnalyzer_66ad10b7, XColumnsSupplier_f0600da9, XTablesSupplier_e1ad0d23):
    """
    Service Class

    represents a service for analyzing a single select statement.
    
    It hides the complexity of parsing and evaluating a single select statement and provides sophisticated methods for accessing a statements filter, group by, having and order criteria, as well as the corresponding select columns and tables. If supported, it even gives access to the parameters.

    See Also:
        `API SingleSelectQueryAnalyzer <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1SingleSelectQueryAnalyzer.html>`_
    """


